# Pythorn

 [![Python](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)

Pythorn is a python module that contains Python-based minimal and clean example  implementations of popular data structures and all major algorithms!!
Mainly for educational purposes




## Features!

  - Easy Documentation
  - Time complexities on the go
  - Get the code right in your editor



## Installation

Pythorn requires Python V3+

```sh
pip install pythorn
```

## Uninstall
If you want to uninstall algorithms, it is as simple as:

```sh
pip3 uninstall -y pythorn
```
